References
==========

Additional Resources
--------------------

For questions, please e-mail:

 * ``parmoo@mcs.anl.gov``

For permissions, see the following:

 * LICENSE_
 * CONTRIBUTING_

Our full user guide is hosted here:

 * ReadTheDocs_

Reference Format
----------------

 * Please use the following to cite ParMOO:

.. code-block:: bibtex

    @techreport{parmoo-docs,
        title       = {{ParMOO}: {P}ython library for parallel multiobjective simulation optimization},
        author      = {Chang, Tyler H. and Wild, Stefan M.},
        institution = {Argonne National Laboratory},
        number      = {Version 0.1.0},
        year        = {2022},
        url         = {https://parmoo.readthedocs.io/en/latest}
    }


.. _CONTRIBUTING: https://github.com/parmoo/parmoo/blob/main/CONTRIBUTING.rst
.. _LICENSE: https://github.com/parmoo/parmoo/blob/main/LICENSE
.. _ReadTheDocs: https://parmoo.readthedocs.org
